Honeybadger.FingerprintAdapter behaviour (Honeybadger v0.15.0) View Source
The callbacks required to implement the FingerprintAdapter behaviour
Link to this section Summary
Callbacks
This function receives a t:Notice.t/0 and must return a string that will be used as a
fingerprint for the request
Link to this section Callbacks
Specs
parse(Notice.noticeable()) :: String.t()
This function receives a t:Notice.t/0 and must return a string that will be used as a
fingerprint for the request:
def parse(notice) do notice.notifier.language <> "_" <> notice.notifier.name end